@@ -15,28 +15,18 @@ SOUND  = 'soundeditor'
 SCRIPT = 'scripteditor'
 
 
-welcome_text = """
-WARNING! SAVING TO .sb FILES WILL DELETE ALL SOUNDS FROM A PROJECT!
-
+welcome_text = \
+"""
 Welcome to M30W!
 
-M30W is a program designed to allow fast
-developing of Scratch projects.
-It uses a unique text syntax to allow typing of
-blocks rather than laggy dragging them around.
+M30W is a program designed to allow fast developing of Scratch projects.
+It uses a unique text syntax to allow typing of blocks rather than laggy
+dragging them around.
 
-M30W currently is in development proccess.
-Therefore, you cannot run scripts.
-Saving to the .sb format is now implemented, so make sure to test it!
-
-Double-click on a sprite to start edit!
-
-Enjoy,
-    the M30W dev team.
-
-Current limitaitions:
-We use kurt to parse scripts and save the .sb
-files, so all its limitations apply:
+M30W currently is in development process, and we haven't implemented
+running scripts yet; Don't look for the green flag ;)
+Editing scripts is working, but because we use kurt to parse scripts, 
+current limitations apply:
 
 - Take care with the "length of" block: strings aren't dropdowns, lists are
 
@@ -48,9 +38,6 @@ files, so all its limitations apply:
   * have trailing whitespace
   * contain special characters, rather obviously: like any of []()<> or equals =
   * be named after a block, eg. a variable called "wait until"
-
-As well as unimplemented features, e.g. such as sound saving.
-They WILL come in the next days!
 """
 
 
