@@ -57,7 +57,7 @@ class App(wx.App):
                 self.GetTopWindow().Close()
                 self._org_except_hook(type, obj, tb)
 
-        if DEBUG: sys.excepthook = excepthook
+        if not DEBUG: sys.excepthook = excepthook
     def CreateGUI(self):
         self.Bind(wx.EVT_CLOSE, self.OnExit)
 
