@@ -1,9 +1,10 @@
 import sys
+import os
+import subprocess
 import wx
-from M30W.IO import save, save_as, open
 from M30W.debug import debug, not_implemented, print_not_implemented_functions
 from errorConsole import ErrorConsole
-from M30W import media
+from M30W import media, config, runtime, IO
 import M30W.sprites
 
 
@@ -34,45 +35,86 @@ class MenuBar(wx.MenuBar):
         for title, items in menus:
             self.Append(Menu(self.parent, items), title)
 
-
-@not_implemented
 def OnNew(e):
-    pass
-
+    IO.new()
 
 def OnOpen(e):
     dialog = wx.FileDialog(None,
-                           message="Please choose file",
+                           message="Please Choose File",
                            wildcard="Scratch 1.4 project file (*.sb)|*.sb"
                                     "|All files (*.*)|*.*",
                            style=wx.OPEN)
 
     if dialog.ShowModal() == wx.ID_OK:
-        open(dialog.GetPath())
+        IO.open(dialog.GetPath())
     dialog.Destroy()
 
-
 def OnSave(e):
     try:
-        save()
+        IO.save()
     except (ValueError, AttributeError):
         OnSaveAs(e)
 
 def OnSaveAs(e):
     dialog = wx.FileDialog(None,
-                           message="Please choose file",
+                           message="Please Choose File",
                            wildcard="Scratch 1.4 project file (*.sb)|*.sb"
                                     "|All files (*.*)|*.*",
                            style=wx.SAVE)
 
     if dialog.ShowModal() == wx.ID_OK:
-        save_as(dialog.GetPath())
-    dialog.Destroy()
-
+        IO.save_as(dialog.GetPath())
+        return True
+    return False
 
 def OnQuit(e):
     wx.GetApp().GetTopWindow().Close()
 
+def default_scratch_path():
+    if sys.platform == 'win32':
+        if os.path.isfile(r'C:\Program Files\Scratch\Scratch.exe'):
+            return r'C:\Program Files\Scratch\Scratch.exe'
+        elif os.path.isfile(r'C:\Program Files (x86)\Scratch\Scratch.exe'):
+            return r'C:\Program Files (x86)\Scratch\Scratch.exe'
+    elif sys.platform == 'linux2':
+        if os.path.isfile('/usr/bin/scratch'):
+            return '/usr/bin/scratch'
+    elif sys.platform == 'darwin':
+        if os.path.isfile('/Applications/Scratch 1.4/Scratch.app'):
+            return '/Applications/Scratch 1.4/Scratch.app'
+    return None
+
+def OnSaveAndOpenInScratch(e):
+    OnSave(e)
+
+    #Assuring event was not canceled from save as dialog
+    if not runtime.project.path: return
+
+    path = config.get_option('SCRATCH_PATH', default_scratch_path())
+    if not path:
+        dialog = wx.FileDialog(None,
+                           message="Please Choose The Scratch Executable",
+                           wildcard="|All files (*.*)|*.*",
+                           style=wx.OPEN)
+        if dialog.ShowModal() == wx.ID_OK:
+            config.set_option('SCRATCH_PATH', dialog.GetPath())
+            path = config.get_option('SCRATCH_PATH', None)
+            dialog.Destroy()
+        else:
+            return
+
+    if sys.platform == 'win32':
+        subprocess.Popen([path, os.path.join(os.path.split(path)[0],
+                                             'Scratch.image'),
+                          runtime.project.path])
+    else:
+        subprocess.Popen([path, runtime.project.path])
+
+def OnReload(e):
+    if not runtime.project.path: return
+    IO.reload()
+
+    
 
 def OnAbout(e):
     description = """M30W is a program designed to allow fast
@@ -103,11 +145,9 @@ along with this program.  If not, see http://www.gnu.org/licenses/"""
 
     wx.AboutBox(info)
 
-
 def OnConsole(event):
     sys.stdout = ErrorConsole(None)
 
-
 def OnPrint(event):
     print_not_implemented_functions()
 
@@ -119,9 +159,10 @@ File = (('&New\tCtrl+N', wx.ID_NEW, OnNew),
         ('Save &As\tCtrl+Shift+S', wx.ID_SAVEAS, OnSaveAs),
         (None, SEPARATOR, None),
         ('&Quit', wx.ID_EXIT, OnQuit))
-Edit = ()
+Edit = (('Save And Open In Scratch', wx.ID_ANY, OnSaveAndOpenInScratch),
+        ('Reload', wx.ID_ANY, OnReload))
 Help = [('Error Console', wx.ID_ANY, OnConsole),
-        ('Print not implemented functions', wx.ID_ANY, OnPrint),
+        ('Print Not Implemented Functions', wx.ID_ANY, OnPrint),
         (None, SEPARATOR, None),
         ('About M30W', wx.ID_ABOUT, OnAbout)]
 menus = (('&File', File), ('&Edit', Edit), ('&Help', Help))
